@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2004 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: Vladimir Nadvornik
  *
@@ -40,7 +40,7 @@ struct _KnownPanes
 	const gchar *config;
 };
 
-static const gchar default_config_histogram[] = 
+static const gchar default_config_histogram[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -49,7 +49,7 @@ static const gchar default_config_histogram[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_title[] = 
+static const gchar default_config_title[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -58,7 +58,7 @@ static const gchar default_config_title[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_keywords[] = 
+static const gchar default_config_keywords[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -67,7 +67,7 @@ static const gchar default_config_keywords[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_comment[] = 
+static const gchar default_config_comment[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -76,7 +76,7 @@ static const gchar default_config_comment[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_exif[] = 
+static const gchar default_config_exif[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -102,7 +102,7 @@ static const gchar default_config_exif[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_file_info[] = 
+static const gchar default_config_file_info[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -115,7 +115,7 @@ static const gchar default_config_file_info[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_location[] = 
+static const gchar default_config_location[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -132,7 +132,7 @@ static const gchar default_config_location[] =
 "    </layout>"
 "</gq>";
 
-static const gchar default_config_copyright[] = 
+static const gchar default_config_copyright[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -147,7 +147,7 @@ static const gchar default_config_copyright[] =
 
 #ifdef HAVE_LIBCHAMPLAIN
 #ifdef HAVE_LIBCHAMPLAIN_GTK
-static const gchar default_config_gps[] = 
+static const gchar default_config_gps[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
@@ -202,9 +202,9 @@ static void bar_expander_move(GtkWidget *widget, gpointer data, gboolean up, gbo
 	if (!expander) return;
 	box = gtk_widget_get_ancestor(expander, GTK_TYPE_BOX);
 	if (!box) return;
-	
+
 	gtk_container_child_get(GTK_CONTAINER(box), expander, "position", &pos, NULL);
-	
+
 	if (single_step)
 		{
 		pos = up ? (pos - 1) : (pos + 1);
@@ -214,7 +214,7 @@ static void bar_expander_move(GtkWidget *widget, gpointer data, gboolean up, gbo
 		{
 		pos = up ? 0 : -1;
 		}
-	
+
 	gtk_box_reorder_child(GTK_BOX(box), expander, pos);
 }
 
@@ -253,14 +253,14 @@ static void bar_expander_add_cb(GtkWidget *widget, gpointer data)
 	const gchar *config;
 
 	if (!id) return;
-	
+
 	while (pane->id)
 		{
 		if (strcmp(pane->id, id) == 0) break;
 		pane++;
 		}
 	if (!pane->id) return;
-	
+
 	config = bar_pane_get_default_config(id);
 	if (config) load_config_from_buf(config, strlen(config), FALSE);
 
@@ -276,20 +276,20 @@ static void bar_menu_popup(GtkWidget *widget)
 	BarData *bd;
 
 	bd = g_object_get_data(G_OBJECT(widget), "bar_data");
-	if (bd) 
+	if (bd)
 		{
 		expander = NULL;
-		bar = widget; 
+		bar = widget;
 		}
 	else
 		{
 		expander = widget;
-		bar = widget->parent;
+		bar = gtk_widget_get_parent(widget);
 		while (bar && !g_object_get_data(G_OBJECT(bar), "bar_data"))
-			bar = bar->parent;
+			bar = gtk_widget_get_parent(bar);
 		if (!bar) return;
 		}
- 
+
 	menu = popup_menu_short_lived();
 
 	if (expander)
@@ -310,20 +310,20 @@ static void bar_menu_popup(GtkWidget *widget)
 		g_object_set_data(G_OBJECT(item), "pane_add_id", pane->id);
 		pane++;
 		}
-	
+
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, bar, 0, GDK_CURRENT_TIME);
 }
 
 
-static gboolean bar_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data) 
-{ 
+static gboolean bar_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
+{
 	if (bevent->button == MOUSE_BUTTON_RIGHT)
 		{
 		bar_menu_popup(widget);
 		return TRUE;
 		}
 	return FALSE;
-} 
+}
 
 
 static void bar_pane_set_fd_cb(GtkWidget *expander, gpointer data)
@@ -344,7 +344,7 @@ void bar_set_fd(GtkWidget *bar, FileData *fd)
 	bd->fd = file_data_ref(fd);
 
 	gtk_container_foreach(GTK_CONTAINER(bd->vbox), bar_pane_set_fd_cb, fd);
-	
+
 	gtk_label_set_text(GTK_LABEL(bd->label_file_name), (bd->fd) ? bd->fd->name : "");
 
 }
@@ -371,19 +371,19 @@ gboolean bar_event(GtkWidget *bar, GdkEvent *event)
 	BarData *bd;
 	GList *list, *work;
 	gboolean ret = FALSE;
-	
+
 	bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	if (!bd) return FALSE;
 
 	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));
-	
+
 	work = list;
 	while (work)
 		{
 		GtkWidget *widget = gtk_bin_get_child(GTK_BIN(work->data));
 		PaneData *pd = g_object_get_data(G_OBJECT(widget), "pane_data");
 		if (!pd) continue;
-	
+
 		if (pd->pane_event && pd->pane_event(widget, event))
 			{
 			ret = TRUE;
@@ -400,21 +400,21 @@ GtkWidget *bar_find_pane_by_id(GtkWidget *bar, PaneType type, const gchar *id)
 	BarData *bd;
 	GList *list, *work;
 	GtkWidget *ret = NULL;
-	
+
 	if (!id || !id[0]) return NULL;
-	
+
 	bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	if (!bd) return NULL;
 
 	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));
-	
+
 	work = list;
 	while (work)
 		{
 		GtkWidget *widget = gtk_bin_get_child(GTK_BIN(work->data));
 		PaneData *pd = g_object_get_data(G_OBJECT(widget), "pane_data");
 		if (!pd) continue;
-	
+
 		if (type == pd->type && strcmp(id, pd->id) == 0)
 			{
 			ret = widget;
@@ -430,12 +430,12 @@ void bar_clear(GtkWidget *bar)
 {
 	BarData *bd;
 	GList *list, *work;
-	
+
 	bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	if (!bd) return;
 
 	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));
-	
+
 	work = list;
 	while (work)
 		{
@@ -452,19 +452,19 @@ void bar_write_config(GtkWidget *bar, GString *outstr, gint indent)
 	GList *list, *work;
 
 	if (!bar) return;
-	
+
 	bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	if (!bd) return;
 
 	WRITE_NL(); WRITE_STRING("<bar ");
-	write_bool_option(outstr, indent, "enabled", GTK_WIDGET_VISIBLE(bar));
+	write_bool_option(outstr, indent, "enabled", gtk_widget_get_visible(bar));
 	write_uint_option(outstr, indent, "width", bd->width);
 	WRITE_STRING(">");
-	
+
 	indent++;
 	WRITE_NL(); WRITE_STRING("<clear/>");
 
-	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));	
+	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));
 	work = list;
 	while (work)
 		{
@@ -489,11 +489,11 @@ void bar_update_expander(GtkWidget *pane)
 {
 	PaneData *pd = g_object_get_data(G_OBJECT(pane), "pane_data");
 	GtkWidget *expander;
-	
+
 	if (!pd) return;
 
-	expander = pane->parent;
-	
+	expander = gtk_widget_get_parent(pane);
+
 	gtk_expander_set_expanded(GTK_EXPANDER(expander), pd->expanded);
 }
 
@@ -502,25 +502,25 @@ void bar_add(GtkWidget *bar, GtkWidget *pane)
 	GtkWidget *expander;
 	BarData *bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	PaneData *pd = g_object_get_data(G_OBJECT(pane), "pane_data");
-	
+
 	if (!bd) return;
 
 	pd->lw = bd->lw;
 	pd->bar = bar;
-	
+
 	expander = gtk_expander_new(NULL);
 	if (pd && pd->title)
 		{
 		gtk_expander_set_label_widget(GTK_EXPANDER(expander), pd->title);
 		gtk_widget_show(pd->title);
 		}
-		
+
 	gtk_box_pack_start(GTK_BOX(bd->vbox), expander, FALSE, TRUE, 0);
-	
-	g_signal_connect(expander, "button_release_event", G_CALLBACK(bar_menu_cb), bd); 
-	
+
+	g_signal_connect(expander, "button_release_event", G_CALLBACK(bar_menu_cb), bd);
+
 	gtk_container_add(GTK_CONTAINER(expander), pane);
-	
+
 	gtk_expander_set_expanded(GTK_EXPANDER(expander), pd->expanded);
 
 	gtk_widget_show(expander);
@@ -533,7 +533,7 @@ void bar_populate_default(GtkWidget *bar)
 {
 	const gchar *populate_id[] = {"histogram", "title", "keywords", "comment", "exif", NULL};
 	const gchar **id = populate_id;
-	
+
 	while (*id)
 		{
 		const gchar *config = bar_pane_get_default_config(*id);
@@ -545,14 +545,14 @@ void bar_populate_default(GtkWidget *bar)
 static void bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation, gpointer data)
 {
 	BarData *bd = data;
-	
+
 	bd->width = allocation->width;
 }
 
 gint bar_get_width(GtkWidget *bar)
 {
 	BarData *bd;
-	
+
 	bd = g_object_get_data(G_OBJECT(bar), "bar_data");
 	if (!bd) return 0;
 
@@ -578,7 +578,7 @@ static void bar_destroy(GtkWidget *widget, gpointer data)
 }
 
 #ifdef HAVE_LIBCHAMPLAIN_GTK
-/* 
+/*
    FIXME: this is an ugly hack that works around this bug:
    https://bugzilla.gnome.org/show_bug.cgi?id=590692
    http://bugzilla.openedhand.com/show_bug.cgi?id=1751
@@ -601,7 +601,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 	bd = g_new0(BarData, 1);
 
 	bd->lw = lw;
-	
+
 	bd->widget = gtk_vbox_new(FALSE, PREF_PAD_GAP);
 	g_object_set_data(G_OBJECT(bd->widget), "bar_data", bd);
 	g_signal_connect(G_OBJECT(bd->widget), "destroy",
@@ -610,7 +610,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 	g_signal_connect(G_OBJECT(bd->widget), "size-allocate",
 			 G_CALLBACK(bar_size_allocate), bd);
 
-	g_signal_connect(G_OBJECT(bd->widget), "button_release_event", G_CALLBACK(bar_menu_cb), bd); 
+	g_signal_connect(G_OBJECT(bd->widget), "button_release_event", G_CALLBACK(bar_menu_cb), bd);
 
 	bd->width = SIDEBAR_DEFAULT_WIDTH;
 	gtk_widget_set_size_request(bd->widget, bd->width, -1);
@@ -639,7 +639,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 	gtk_viewport_set_shadow_type(GTK_VIEWPORT(gtk_bin_get_child(GTK_BIN(scrolled))), GTK_SHADOW_NONE);
 
 #ifdef HAVE_LIBCHAMPLAIN_GTK
-	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(scrolled))), "unrealize", G_CALLBACK(bar_unrealize_clutter_fix_cb), NULL); 
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(scrolled))), "unrealize", G_CALLBACK(bar_unrealize_clutter_fix_cb), NULL);
 #endif
 
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_NONE);
@@ -660,13 +660,13 @@ GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names,
 
 		if (READ_BOOL_FULL("enabled", enabled)) continue;
 		if (READ_INT_FULL("width", width)) continue;
-		
+
 
 		log_printf("unknown attribute %s = %s\n", option, value);
 		}
-	
+
 	gtk_widget_set_size_request(bar, width, -1);
-	if (enabled) 
+	if (enabled)
 		{
 		gtk_widget_show(bar);
 		}
@@ -696,7 +696,7 @@ GtkWidget *bar_pane_expander_title(const gchar *title)
 gboolean bar_pane_translate_title(PaneType type, const gchar *id, gchar **title)
 {
 	const KnownPanes *pane = known_panes;
-	
+
 	if (!title) return FALSE;
 	while (pane->id)
 		{
@@ -704,9 +704,9 @@ gboolean bar_pane_translate_title(PaneType type, const gchar *id, gchar **title)
 		pane++;
 		}
 	if (!pane->id) return FALSE;
-	
+
 	if (*title && **title && strcmp(pane->title, *title) != 0) return FALSE;
-	
+
 	g_free(*title);
 	*title = g_strdup(_(pane->title));
 	return TRUE;
@@ -715,7 +715,7 @@ gboolean bar_pane_translate_title(PaneType type, const gchar *id, gchar **title)
 const gchar *bar_pane_get_default_config(const gchar *id)
 {
 	const KnownPanes *pane = known_panes;
-	
+
 	while (pane->id)
 		{
 		if (strcmp(pane->id, id) == 0) break;
@@ -724,5 +724,5 @@ const gchar *bar_pane_get_default_config(const gchar *id)
 	if (!pane->id) return NULL;
 	return pane->config;
 }
-	
+
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
