@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- *  Copyright (C) 2008 - 2010 The Geeqie Team
+ *  Copyright (C) 2008 - 2012 The Geeqie Team
  *
  *  Authors:
  *    Support for Exif file format, originally written by Eric Swalens.
@@ -73,6 +73,7 @@
 
 #include "main.h"
 #include "exif-int.h"
+#include "jpeg_parser.h"
 
 #include "format_raw.h"
 #include "ui_fileops.h"
@@ -1086,7 +1087,7 @@ static gint exif_jpeg_parse(ExifData *exif,
 		return -2;
 		}
 
-	if (exif_jpeg_segment_find(data, size, JPEG_MARKER_APP1,
+	if (jpeg_segment_find(data, size, JPEG_MARKER_APP1,
 				   "Exif\x00\x00", 6,
 				   &seg_offset, &seg_length))
 		{
@@ -1280,11 +1281,6 @@ ExifData *exif_read(gchar *path, gchar *sidecar_path, GHashTable *modified_xmp)
 
 	if (exif) exif->items = g_list_reverse(exif->items);
 
-#if 0
-	exif_write_data_list(exif, stdout, TRUE);
-	exif_write_data_list(exif, stdout, FALSE);
-#endif
-
 	return exif;
 }
 
@@ -1603,12 +1599,12 @@ GList *exif_get_metadata(ExifData *exif, const gchar *key, MetadataFormat format
 {
 	gchar *str;
 	ExifItem *item;
-	
+
 	if (!key) return NULL;
-	
+
 	/* convert xmp key to exif key */
 	if (strcmp(key, "Xmp.tiff.Orientation") == 0) key = "Exif.Image.Orientation";
-	
+
 	if (format == METADATA_FORMATTED)
 		{
 		gchar *text;
@@ -1619,11 +1615,11 @@ GList *exif_get_metadata(ExifData *exif, const gchar *key, MetadataFormat format
 
 	item = exif_get_item(exif, key);
 	if (!item) return NULL;
-	
+
 	str = exif_item_get_data_as_text_full(item, format);
-	
+
 	if (!str) return NULL;
-	
+
 	return g_list_append(NULL, str);
 }
 
@@ -1645,13 +1641,13 @@ guchar *exif_get_preview(ExifData *exif, guint *data_len, gint requested_width,
 	guchar *map_data;
 	size_t map_len;
 	int fd;
-	
+
 	if (!exif) return NULL;
 	path = exif->path;
 
 	fd = open(path, O_RDONLY);
-		
-		
+
+
 	if (fd == -1)
 		{
 		return 0;
@@ -1682,7 +1678,7 @@ guchar *exif_get_preview(ExifData *exif, guint *data_len, gint requested_width,
 		ud->ptr = map_data + offset;
 		ud->map_data = map_data;
 		ud->map_len = map_len;
-		
+
 		exif_unmap_list = g_list_prepend(exif_unmap_list, ud);
 		return ud->ptr;
 		}
@@ -1695,7 +1691,7 @@ guchar *exif_get_preview(ExifData *exif, guint *data_len, gint requested_width,
 void exif_free_preview(guchar *buf)
 {
 	GList *work = exif_unmap_list;
-	
+
 	while (work)
 		{
 		UnmapData *ud = (UnmapData *)work->data;
