@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- *  Copyright (C) 2008 - 2010 The Geeqie Team
+ *  Copyright (C) 2008 - 2012 The Geeqie Team
  *
  *  Authors:
  *    Support for Exif file format, originally written by Eric Swalens.
@@ -27,7 +27,7 @@
 #ifndef __EXIF_H
 #define __EXIF_H
 
-#define EXIF_FORMATTED(x) "formatted."x
+#define EXIF_FORMATTED() "formatted."
 #define EXIF_FORMATTED_LEN (sizeof(EXIF_FORMATTED()) - 1)
 
 /*
@@ -161,9 +161,6 @@ guchar *exif_get_color_profile(ExifData *exif, guint *data_len);
 void exif_add_jpeg_color_profile(ExifData *exif, guchar *cp_data, guint cp_length);
 
 
-gboolean exif_jpeg_segment_find(guchar *data, guint size,
-                                guchar app_marker, const gchar *magic, guint magic_len,
-                                guint *seg_offset, guint *seg_length);
 gboolean exif_jpeg_parse_color(ExifData *exif, guchar *data, guint size);
 
 /*raw support */
