@@ -1,7 +1,7 @@
 /*
  * (SLIK) SimpLIstic sKin functions
  * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: John Ellis
  *
@@ -49,25 +49,6 @@ void print_term(const gchar *text_utf8)
 	g_free(text_l);
 }
 
-static void encoding_dialog(const gchar *path);
-
-static gboolean encoding_dialog_idle(gpointer data)
-{
-	gchar *path = data;
-
-	encoding_dialog(path);
-	g_free(path);
-
-	return FALSE;
-}
-
-static gint encoding_dialog_delay(gpointer data)
-{
-	g_idle_add(encoding_dialog_idle, data);
-
-	return 0;
-}
-
 static void encoding_dialog(const gchar *path)
 {
 	static gboolean warned_user = FALSE;
@@ -76,14 +57,6 @@ static void encoding_dialog(const gchar *path)
 	const gchar *lc;
 	const gchar *bf;
 
-	/* check that gtk is initialized (loop is level > 0) */
-	if (gtk_main_level() == 0)
-		{
-		/* gtk not initialized */
-		gtk_init_add(encoding_dialog_delay, g_strdup(path));
-		return;
-		}
-
 	if (warned_user) return;
 	warned_user = TRUE;
 
@@ -107,7 +80,7 @@ static void encoding_dialog(const gchar *path)
 		name = g_convert(path, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
 		string = g_string_append(string, _("\nPreferred encoding appears to be UTF-8, however the file:\n"));
 		g_string_append_printf(string, "\"%s\"\n", (name) ? name : _("[name not displayable]"));
-		
+
 		if (g_utf8_validate(path, -1, NULL))
 			g_string_append_printf(string, _("\"%s\" is encoded in valid UTF-8."), (name) ? name : _("[name not displayable]"));
 		else
@@ -196,7 +169,7 @@ const gchar *homedir(void)
 
 	if (!home)
 		home = path_to_utf8(getenv("HOME"));
-	
+
 	if (!home)
 		home = path_to_utf8(g_get_home_dir());
 
@@ -211,7 +184,7 @@ static gchar *xdg_dir_get(const gchar *key, const gchar *fallback)
 		{
     		return g_build_filename(homedir(), fallback, NULL);
     		}
-	
+
 	return path_to_utf8(dir);
 }
 
@@ -220,7 +193,7 @@ const gchar *xdg_data_home_get(void)
 	static const gchar *xdg_data_home = NULL;
 
 	if (xdg_data_home) return xdg_data_home;
-    	
+
 	xdg_data_home = xdg_dir_get("XDG_DATA_HOME", ".local/share");
 
 	return xdg_data_home;
@@ -231,7 +204,7 @@ const gchar *xdg_config_home_get(void)
 	static const gchar *xdg_config_home = NULL;
 
 	if (xdg_config_home) return xdg_config_home;
-    	
+
 	xdg_config_home = xdg_dir_get("XDG_CONFIG_HOME", ".config");
 
 	return xdg_config_home;
@@ -242,7 +215,7 @@ const gchar *xdg_cache_home_get(void)
 	static const gchar *xdg_cache_home = NULL;
 
 	if (xdg_cache_home) return xdg_cache_home;
-    	
+
 	xdg_cache_home = xdg_dir_get("XDG_CACHE_HOME", ".cache");
 
 	return xdg_cache_home;
@@ -251,7 +224,7 @@ const gchar *xdg_cache_home_get(void)
 const gchar *get_rc_dir(void)
 {
 	static gchar *rc_dir = NULL;
-	
+
 	if (rc_dir) return rc_dir;
 
 	if (USE_XDG)
@@ -289,7 +262,7 @@ const gchar *get_trash_dir(void)
 	static gchar *trash_dir = NULL;
 
 	if (trash_dir) return trash_dir;
-	
+
 	if (USE_XDG)
 		{
 		trash_dir = g_build_filename(xdg_data_home_get(), GQ_APPNAME_LC, GQ_TRASH_DIR, NULL);
@@ -490,8 +463,14 @@ gboolean copy_file_attributes(const gchar *s, const gchar *t, gint perms, gint m
 
 		/* set the dest file attributes to that of source (ignoring errors) */
 
-		if (perms && chown(tl, st.st_uid, st.st_gid) < 0) ret = FALSE;
-		if (perms && chmod(tl, st.st_mode) < 0) ret = FALSE;
+		if (perms)
+			{
+			ret = chown(tl, st.st_uid, st.st_gid);
+			/* Ignores chown errors, while still doing chown
+			   (so root still can copy files preserving ownership) */
+			ret = TRUE;
+			if (chmod(tl, st.st_mode) < 0) ret = FALSE;
+			}
 
 		tb.actime = st.st_atime;
 		tb.modtime = st.st_mtime;
@@ -539,15 +518,15 @@ gboolean copy_file(const gchar *s, const gchar *t)
 
 	fi = fopen(sl, "rb");
 	if (!fi) goto end;
-	
+
 	/* First we write to a temporary file, then we rename it on success,
 	   and attributes from original file are copied */
 	randname = g_strconcat(tl, ".tmp_XXXXXX", NULL);
 	if (!randname) goto end;
-	
+
 	fd = g_mkstemp(randname);
 	if (fd == -1) goto end;
-	
+
 	fo = fdopen(fd, "wb");
 	if (!fo) {
 		close(fd);
@@ -568,7 +547,7 @@ gboolean copy_file(const gchar *s, const gchar *t)
 
 	if (rename(randname, tl) < 0) {
 		unlink(randname);
-		goto end; 	
+		goto end;
 	}
 
 	ret = copy_file_attributes(s, t, TRUE, TRUE);
@@ -822,7 +801,7 @@ void parse_out_relatives(gchar *path)
 				continue;
 				}
 			}
-	
+
 		if (s != t) path[t] = path[s];
 		t++;
 		s++;
@@ -886,7 +865,7 @@ gboolean recursive_mkdir_if_not_exists(const gchar *path, mode_t mode)
 					p[0] = '\0';
 					end = FALSE;
 					}
-				
+
 				if (!isdir(npath))
 					{
 					DEBUG_1("creating sub dir:%s", npath);
@@ -897,7 +876,7 @@ gboolean recursive_mkdir_if_not_exists(const gchar *path, mode_t mode)
 						return FALSE;
 						}
 					}
-				
+
 				if (!end) p[0] = G_DIR_SEPARATOR;
 				}
 			}
